#!/bin/csh -f

if ( $#argv != 3 ) then
    echo "Usage : "$0" (FITS data table) (# of frame per position) (Header)"
    exit 1
endif

set FTABLE=$1
set NPOINT=$2
set HEADER=$3

echo "### Preparation ###"
set DITH=20
@ DITH2 = $DITH * 2
set NFRAME=`gawk -v np=$NPOINT 'END{print(NR/np)}' $FTABLE`
echo NFRAME=$NFRAME
gawk '{n=split($1,a,"/");print("ldata/"a[n])}' $FTABLE | sed 's/.fits/.imh/g' > ldata.tbl
sed 's/ldata/mldata/g' ldata.tbl > mldata.tbl
sed 's/.imh/.imh[257:768,257:768]/g' ldata.tbl > pldata.tbl
gawk -v nf=$NFRAME '{if(i<1) print($0); i++; if(i==nf) i=0;}' ldata.tbl > ldata.1.tbl
gawk -v nf=$NFRAME '{if(i>=1) print($0); i++; if(i==nf) i=0;}' ldata.tbl > ldata.2.tbl
sed 's/.imh/.imh[257:768,257:768]/g' ldata.1.tbl > pldata.1.tbl

echo "### Flat-fielding ###"
echo "imdel @ldata.tbl" > cl.com
echo "imarith @"$FTABLE" / ./flat.fits @ldata.tbl" >> cl.com
cat cl.com | cl

echo "### Offset rejection in Quad 2 ###"
echo "offsetrej @ldata.tbl" | cl

echo "### Preparation for MKSUBGR command ###"
echo "del level.tbl" > cl.com
echo "imstatistics @pldata.1.tbl field=mean fo- > level.tbl" >> cl.com
cat cl.com | cl
awk '{s+=$1;i++;}END{print(s/i)}' level.tbl > tmp.txt
echo "imdel sky1,sky2" > cl.com
echo "imdel sky*.imh" >> cl.com
echo "del bkg1.tbl,bkg2.tbl" >> cl.com
cat cl.com | cl

echo "### MKSUBGR command ###"
gawk -v nf=1 '{print("mksubgr @ldata.1.tbl sky1 1 "nf" "$1" 257 768 257 768 bkg1.tbl")}' tmp.txt | cl
gawk -v nf=$NFRAME '{print("mksubgr @ldata.2.tbl sky2 1 "nf-1" "$1" 257 768 257 768 bkg2.tbl")}' tmp.txt | cl

echo "### Sky-subtraction ###"
echo "imarith @ldata.1.tbl - sky1 @ldata.1.tbl" > cl.com
echo "imarith @ldata.2.tbl - sky2 @ldata.2.tbl" >> cl.com
echo "imdel tmp2*.imh,tmp2*.fits" >> cl.com
cat cl.com | cl
ls sky2.???.imh > tmp.tbl
sed -e 's/sky2/tmp2/g' tmp.tbl > tmp2.tbl
echo "imarith @tmp.tbl - sky2 @tmp2.tbl" > cl.com
echo "imdel tmp.tot*" >> cl.com
echo "del tmp.log,tmp.offset" >> cl.com
cat cl.com | cl

echo "### Shift and Combine ###"
echo "shiftcomb @tmp2.tbl tmp.tot 1 30.0 tmp.log tmp.offset" | cl
\rm offset.$HEADER
cp tmp.offset offset.$HEADER
\rm RESULTS/offset.$HEADER
mv offset.$HEADER RESULTS/

echo "### Object Detection ###"
#calculate background sigma
echo "del tmp.sigma" > cl.com
echo "imstatrej tmp.tot[300:600,300:600] 3 > tmp.sigma" >> cl.com
cat cl.com | cl

set SIGMA=`gawk '{if(NR==1)print($3*2)}' tmp.sigma`
echo "noao" > cl.com
echo "digiphot" >> cl.com
echo "apphot" >> cl.com
echo "del tmp.tot.coo" >> cl.com
echo "imdel tmp1.fits,tmp1.imh" >> cl.com
echo "gauss tmp.tot tmp1 2.5" >> cl.com
if ($DITH > 0) then
	echo "imshift tmp1 tmp1 "$DITH" "$DITH" boundary=constant">> cl.com
	echo "imshift tmp1 tmp1 -"$DITH2" 0 boundary=constant" >> cl.com
	echo "imshift tmp1 tmp1 0 -"$DITH2" boundary=constant" >> cl.com
	echo "imshift tmp1 tmp1 "$DITH" "$DITH" boundary=constant" >> cl.com
endif
echo "daofind tmp1 output="tmp.tot.coo" fwhmpsf=15 thresho=4 verify- sigma="$SIGMA "sharplo=-0.5 sharphi=5 roundlo=-5 roundhi=5" >> cl.com
echo "displ tmp.tot 1 fi+" >> cl.com
echo "tvmark 1 tmp.tot.coo number+" >> cl.com
cat cl.com | cl
./offsettbl tmp.tot.coo RESULTS/offset.$HEADER MASK/$HEADER

echo "### $0 Finished ###"
echo $NPOINT" points dithering."
echo "Offset pattern file is saved as "RESULTS/offset.$HEADER
echo "Offset pattern is : "
cat RESULTS/offset.$HEADER
echo "Sigma value for daofind is " $SIGMA
echo "Mask of objcts are saved as"
ls MASK/$HEADER.0??.tbl | cat
echo "."
