#!/bin/csh -f


if ( $#argv != 3 ) then
    echo "Usage : "$0" (FITS data table) (# of frame per position) (Header)"
    exit 1
endif

set FTABLE=$1
set NPOINT=$2
set HEADER=$3
set NFRAME=`gawk -v np=$NPOINT 'END{print(NR/np)}' $FTABLE`
echo $NFRAME

echo "### Erase objects ###"
echo "imdel @mldata.tbl" | cl
set i=1
while($i <= $NPOINT)
  sed "s/XXX/$i/g" erasestd.base | sed "s/XNFX/$NFRAME/g" | sed "s/XNUMX/$HEADER/g" | csh
  @ i += 1
end

echo "imdel @ldata.tbl" > cl.com
echo "imcopy @mldata.tbl  @ldata.tbl" >> cl.com
echo "imarith @ldata.1.tbl + sky1 @ldata.1.tbl" >> cl.com
echo "imarith @ldata.2.tbl + sky2 @ldata.2.tbl" >> cl.com
cat cl.com | cl

echo "### Re-create sky frames ###"
awk '{s+=$1;i++;}END{print(s/i)}' level.tbl > tmp.txt
echo "imdel noobjsky1,noobjsky2" > cl.com
echo "imdel noobjsky*.imh" >> cl.com
echo "del bkg1.tbl,bkg2.tbl" >> cl.com
cat cl.com | cl
gawk -v nf=1 '{print("mksubgr @ldata.1.tbl noobjsky1 1 "nf" "$1" 257 768 257 768 bkg1.tbl")}' tmp.txt | cl
gawk -v nf=$NFRAME '{print("mksubgr @ldata.2.tbl noobjsky2 1 "nf-1" "$1" 257 768 257 768 bkg2.tbl")}' tmp.txt | cl

echo "### Re-reduce frames ###"
echo "imdel @ldata.tbl" > cl.com
echo "imarith @"$FTABLE" / ./flat.fits @ldata.tbl" >> cl.com
#echo "del level.tbl" >> cl.com
#echo "imstatistics @pldata.1.tbl field=mean fo- > level.tbl" >> cl.com
cat cl.com | cl
echo "offsetrej @ldata.tbl" | cl
awk '{s+=$1;i++;}END{print(s/i)}' level.tbl > tmp.txt
echo "imdel sky1,sky2" > cl.com
echo "imdel sky*.imh" >> cl.com
echo "del bkg1.tbl,bkg2.tbl" >> cl.com
cat cl.com | cl
gawk -v nf=1 '{print("mksubgr @ldata.1.tbl sky1 1 "nf" "$1" 257 768 257 768 bkg1.tbl")}' tmp.txt | cl
gawk -v nf=$NFRAME '{print("mksubgr @ldata.2.tbl sky2 1 "nf-1" "$1" 257 768 257 768 bkg2.tbl")}' tmp.txt | cl

echo "### Subtract new sky frames ###"
echo "imarith @ldata.1.tbl - noobjsky1 @ldata.1.tbl" > cl.com
echo "imarith @ldata.2.tbl - noobjsky2 @ldata.2.tbl" >> cl.com
cat cl.com | cl

echo "### Modify ###"
echo "imdel @mldata.tbl" | cl
set i=1
while($i <= $NPOINT)
  sed "s/XXX/$i/g" modify.base | sed "s/XNFX/$NFRAME/g" | sed "s/XNUMX/$HEADER/g" | csh
  @ i += 1
end

echo "### Shift and Combine all frames ###"
\rm RESULTS/$HEADER.fits
\rm RESULTS/$HEADER.log
\rm RESULTS/offset2.$HEADER
echo "imdel "$HEADER".*imh" | cl
echo "shiftcomb2 @mldata.tbl RESULTS/"$HEADER".fits "$NFRAME" 20.0 RESULTS/"$HEADER".log RESULTS/offset2."$HEADER" RESULTS/offset."$HEADER" 0" | cl

echo "### Erase temporary frames ###"
echo "imdel *.imh" | cl
echo "imdel @ldata.tbl" | cl
echo "imdel @mldata.tbl" | cl

echo "### $0 Finished ###"
echo "Final frame saved as RESULTS/"$HEADER".fits"
echo "Log of final shift & combine is saved as RESULTS/"$HEADER".log"
echo "Offset pattern of final shift & combine is saved as RESULTS/offset2."$HEADER
